####################
インストール
####################

.. code-block:: bash

    pip install ebilab

****************************************
ドライバの設定
****************************************

実験装置の制御を行うには、VISAドライバーが必要になります。
一般的には、制御対象のメーカーに応じて Keysight-VISA か NI-VISA をインストールすれば問題ありません。
なお、両方ともにインストールする必要がある場合があります。

